# Changelog

## 0.1.0-alpha.1 (2024-08-08)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/squack-io/flux-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([2425a4b](https://github.com/squack-io/flux-python/commit/2425a4b1289bb936cc18dcc52bc13fab221b9750))
* **api:** update via SDK Studio ([#4](https://github.com/squack-io/flux-python/issues/4)) ([38f9ce9](https://github.com/squack-io/flux-python/commit/38f9ce982e7e1a0cbcd114356df7410dab7347b4))


### Chores

* go live ([#1](https://github.com/squack-io/flux-python/issues/1)) ([73a3b1e](https://github.com/squack-io/flux-python/commit/73a3b1e5dca528c77bc459943b40a58c842b51d9))
* update SDK settings ([#3](https://github.com/squack-io/flux-python/issues/3)) ([337b583](https://github.com/squack-io/flux-python/commit/337b583a9cd96ef736cde9666f5ec9e60e475a0a))
